==> kaya_module_sdk-2.0.tar.gz: kaya_module_sdk-2.0/kaya_module_sdk/src/module/config.py <==
import logging
from abc import ABC, abstractmethod
from typing import Annotated, get_type_hints

log = logging.getLogger(__name__)


class KConfig(ABC):
    name: str
    version: str
    display_label: str
    category: str
    description: str
    author: str
    author_email: str
    MANIFEST: dict
    DEFAULTS: dict
    _mandatory: list

    def __init__(self, *args, **kwargs):
        self._mandatory = ["name", "version", "category", "author"]
        self.name = kwargs.get("name", "")
        self.version = kwargs.get("version", "")
        self.display_label = kwargs.get("display_label", "")
        self.category = kwargs.get("category", "")
        self.description = kwargs.get("description", "")
        self.author = kwargs.get("author", "")
        self.author_email = kwargs.get("author_email", "")
        self.MANIFEST = self._format_metadata(*args, **kwargs)

    #   @pysnooper.snoop()
    def _format_metadata(self, *args, **kwargs):
        meta = {
            "PACKAGE": {
                "NAME": self.name,
                "LABEL": self.display_label,
                "VERSION": self.version,
                "DESCRIPTION": self.description,
                "CATEGORY": self.category,
            },
            "MODULES": {},
        }
        for arg in args:
            meta["MODULES"].update(
                {
                    arg[0]: {
                        "NAME": arg[1].config.display_label or arg[1].config.name,
                        "VERSION": arg[1].config.version,
                        "DESCRIPTION": arg[1].config.description,
                        "CATEGORY": arg[1].config.category,
                    }
                }
            )
        return meta

    def recompute_package_metadata(self, *args, **kwargs):
        self.MANIFEST = self._format_metadata(*args, **kwargs)
        return self.MANIFEST

    def metadata(self):
        return get_type_hints(self, include_extras=True)

    def data(self):
        return self.__dict__

==> kaya_module_sdk-2.1.5.tar.gz: kaya_module_sdk-2.1.5/kaya_module_sdk/src/module/config.py <==
# import pysnooper  # type: ignore

from logging import Logger, getLogger
from typing import get_type_hints
from abc import ABC

log: Logger = getLogger(__name__)


class KConfig(ABC):
    name: str
    version: str
    display_label: str
    category: str
    description: str
    author: str
    author_email: str
    MANIFEST: dict
    DEFAULTS: dict
    _mandatory: list

    def __init__(self, *args, **kwargs):
        self._mandatory = ["name", "version", "category", "author"]
        self.name = kwargs.get("name", "")
        self.version = kwargs.get("version", "")
        self.display_label = kwargs.get("display_label", "")
        self.category = kwargs.get("category", "")
        self.description = kwargs.get("description", "")
        self.author = kwargs.get("author", "")
        self.author_email = kwargs.get("author_email", "")
        self.MANIFEST = self._format_metadata(*args)

    #   @pysnooper.snoop()
    def _format_metadata(self, *args):
        meta = {
            "PACKAGE": {
                "NAME": self.name,
                "LABEL": self.display_label,
                "VERSION": self.version,
                "DESCRIPTION": self.description,
                "CATEGORY": self.category,
            },
            "MODULES": {},
        }
        for arg in args:
            meta["MODULES"].update({arg[0]: arg[1].manifest})
        return meta

    def recompute_package_metadata(self, *args, **kwargs):
        self.MANIFEST = self._format_metadata(*args, **kwargs)
        return self.MANIFEST

    def metadata(self):
        return get_type_hints(self, include_extras=True)

    def data(self):
        return self.__dict__
